# Credits

## Development Lead

* James R. Craig <jrcraig@uwaterloo.ca> [@analytophile](https://github.com/analytophile)

## Co-Developers

* Robert Chlumsky <rchlumsk@uwaterloo.ca> [@rchlumsk](https://github.com/rchlumsk)
* David Huard <huard.david@ouranos.ca> [@huard](https://github.com/huard)
* Juliane Mai <juliane.mai@ufz.de> [@julemai](https://github.com/julemai)

## Contributors

* Trevor James Smith <smith.trevorj@ouranos.ca> [@Zeitsperre](https://github.com/Zeitsperre)
* Andre Della Libera Zanchetta <andre.dellaliberazanchetta@umanitoba.ca> [@adlzanchetta](https://github.com/adlzanchetta)
